==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/AuthenticatorEnrollmentPolicyRuleConditions.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.AuthenticatorEnrollmentPolicyRuleConditionsPeople;
import com.okta.sdk.resource.model.PolicyNetworkCondition;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * AuthenticatorEnrollmentPolicyRuleConditions
 */
@JsonPropertyOrder({ AuthenticatorEnrollmentPolicyRuleConditions.JSON_PROPERTY_NETWORK,
        AuthenticatorEnrollmentPolicyRuleConditions.JSON_PROPERTY_PEOPLE })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class AuthenticatorEnrollmentPolicyRuleConditions implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_NETWORK = "network";
    private PolicyNetworkCondition network;

    public static final String JSON_PROPERTY_PEOPLE = "people";
    private AuthenticatorEnrollmentPolicyRuleConditionsPeople people;

    public AuthenticatorEnrollmentPolicyRuleConditions() {
    }

    public AuthenticatorEnrollmentPolicyRuleConditions network(PolicyNetworkCondition network) {

        this.network = network;
        return this;
    }

    /**
     * Get network
     *
     * @return network
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_NETWORK)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PolicyNetworkCondition getNetwork() {
        return network;
    }

    @JsonProperty(JSON_PROPERTY_NETWORK)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setNetwork(PolicyNetworkCondition network) {
        this.network = network;
    }

    public AuthenticatorEnrollmentPolicyRuleConditions people(
            AuthenticatorEnrollmentPolicyRuleConditionsPeople people) {

        this.people = people;
        return this;
    }

    /**
     * Get people
     *
     * @return people
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PEOPLE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public AuthenticatorEnrollmentPolicyRuleConditionsPeople getPeople() {
        return people;
    }

    @JsonProperty(JSON_PROPERTY_PEOPLE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPeople(AuthenticatorEnrollmentPolicyRuleConditionsPeople people) {
        this.people = people;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AuthenticatorEnrollmentPolicyRuleConditions authenticatorEnrollmentPolicyRuleConditions = (AuthenticatorEnrollmentPolicyRuleConditions) o;
        return Objects.equals(this.network, authenticatorEnrollmentPolicyRuleConditions.network)
                && Objects.equals(this.people, authenticatorEnrollmentPolicyRuleConditions.people);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(network, people);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AuthenticatorEnrollmentPolicyRuleConditions {\n");
        sb.append("    network: ").append(toIndentedString(network)).append("\n");
        sb.append("    people: ").append(toIndentedString(people)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/AuthenticatorEnrollmentPolicyRuleConditions.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.AuthenticatorEnrollmentPolicyRuleConditionsPeople;
import com.okta.sdk.resource.model.PolicyNetworkCondition;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * AuthenticatorEnrollmentPolicyRuleConditions
 */
@JsonPropertyOrder({ AuthenticatorEnrollmentPolicyRuleConditions.JSON_PROPERTY_NETWORK,
        AuthenticatorEnrollmentPolicyRuleConditions.JSON_PROPERTY_PEOPLE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class AuthenticatorEnrollmentPolicyRuleConditions implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_NETWORK = "network";
    private PolicyNetworkCondition network;

    public static final String JSON_PROPERTY_PEOPLE = "people";
    private AuthenticatorEnrollmentPolicyRuleConditionsPeople people;

    public AuthenticatorEnrollmentPolicyRuleConditions() {
    }

    public AuthenticatorEnrollmentPolicyRuleConditions network(PolicyNetworkCondition network) {

        this.network = network;
        return this;
    }

    /**
     * Get network
     *
     * @return network
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_NETWORK)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PolicyNetworkCondition getNetwork() {
        return network;
    }

    @JsonProperty(JSON_PROPERTY_NETWORK)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setNetwork(PolicyNetworkCondition network) {
        this.network = network;
    }

    public AuthenticatorEnrollmentPolicyRuleConditions people(
            AuthenticatorEnrollmentPolicyRuleConditionsPeople people) {

        this.people = people;
        return this;
    }

    /**
     * Get people
     *
     * @return people
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PEOPLE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public AuthenticatorEnrollmentPolicyRuleConditionsPeople getPeople() {
        return people;
    }

    @JsonProperty(JSON_PROPERTY_PEOPLE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPeople(AuthenticatorEnrollmentPolicyRuleConditionsPeople people) {
        this.people = people;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AuthenticatorEnrollmentPolicyRuleConditions authenticatorEnrollmentPolicyRuleConditions = (AuthenticatorEnrollmentPolicyRuleConditions) o;
        return Objects.equals(this.network, authenticatorEnrollmentPolicyRuleConditions.network)
                && Objects.equals(this.people, authenticatorEnrollmentPolicyRuleConditions.people);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(network, people);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AuthenticatorEnrollmentPolicyRuleConditions {\n");
        sb.append("    network: ").append(toIndentedString(network)).append("\n");
        sb.append("    people: ").append(toIndentedString(people)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
